﻿using PdfSharp.Pdf;
using System;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;

namespace MapPrinterDemo_WebForms
{
    public partial class WebForm1 : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                // Set the Map Unit. The reason for setting it to DecimalDegrees is that is what the shapefile’s unit of measure is inherently in.
                Map1.MapUnit = GeographyUnit.Meter;
                Map1.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);

                var googleLayer = new GoogleMapsLayer("TileCache", "gme-valmontindustries", "-J7YzyRJpepGq9HwRM3LGXyDM04=");
                Map1.StaticOverlay.Layers.Add("GoogleLayer", googleLayer);

                InMemoryFeatureLayer markerLayer = new InMemoryFeatureLayer();
                markerLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new PointStyle(new GeoImage(MapPath("/theme/default/img/marker.gif")));
                markerLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle.XOffsetInPixel = -10.5F;
                markerLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle.YOffsetInPixel = -25.0F;
                markerLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                markerLayer.InternalFeatures.Add(new Feature(-8922952.93266, 2984101.58384));
                markerLayer.InternalFeatures.Add(new Feature(-10830821.09801, 4539747.98328));
                markerLayer.InternalFeatures.Add(new Feature(-12454955.13517, 4980025.26614));
                markerLayer.InternalFeatures.Add(new Feature(-10772117.52067, 3864656.14956));
                Map1.StaticOverlay.Layers.Add("MarkerLayer", markerLayer);
            }
        }

        protected void btnPrintMap_Click(object sender, EventArgs e)
        {
            var doc = new PdfDocument();
            var page__1 = doc.AddPage();
            page__1.Orientation = PdfSharp.PageOrientation.Landscape;

            var canvas = new PdfGeoCanvas();
            canvas.Dpi = 100;
            canvas.BeginDrawing(page__1, new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962), GeographyUnit.Meter);

            var googleLayer = Map1.StaticOverlay.Layers["GoogleLayer"];
            googleLayer.Open();
            googleLayer.Draw(canvas, new Collection<SimpleCandidate>());
            googleLayer.Close();

            var markerLayer = Map1.StaticOverlay.Layers["MarkerLayer"];
            markerLayer.Open();
            markerLayer.Draw(canvas, new Collection<SimpleCandidate>());
            markerLayer.Close();
            canvas.EndDrawing();

            doc.Save(@"c:\MapSuitePdfMap.pdf");
        }
    }
}